/**************************************************************************************
 ** Class name: Display
 ** Author: A.J. Lattanze, CMU
 ** Date: 12/29/99
 ** Version 1.0
 **
 ** Adapted for use at ETS by Roger Champagne, 2002-May-21
 ***************************************************************************************
 ** Purpose: Assignment 2 for LOG420, Architecture et conception de logiciels.
 ** This class will display lists (StudentList and CourseList objects).  
 **
 ** Abstract: A variety of methods are provided that display Student object, Course 
 ** objects, StudentList objects, and CourseList objects to the terminal.  The methods 
 ** are in this class are as follows:
 **
 **	private void LineCheck( int LinesToAdd ) - Counts the number of lines that has
 **	been printed.  One a set number of lines has been printed, the user is asked to 
 **	"press the enter key to continue".  This prevents lines of text from scrolling
 **	off of the page
 **
 **	public void DisplayStudent( Student StudentObject ) - Displays a student object
 **	elements as follows:
 **
 **		FirstName - Student's first name
 **		LastName - Student's last name
 **		StudentID - Student's ID number
 **		Program - Student's program affiliation (e.g. LOG, CGL, ELE, etc.)
 **
 **	Note that the courses taken by the student are not listed and the courses the 
 **	student has registered for are not listed.  
 **
 **	public void DisplayCourse( Course CourseObject ) - Displays a course object
 **	elements as follows:
 **
 **		CourseName - Course title
 **		CourseID - Course number 
 **		Section - Course section
 **		Days - Days the course will be held on
 **		StartTime - Start time of the course
 **		StopTime - Stop time of the course
 **		Instructor - Instructor Name
 **
 **	Note that the students registered for the course are not listed by this method.  
 **
 **	public void DisplayStudentsRegistered( Course CourseObject ) - This method lists
 **	the students that have registered for the course (CourseObject).
 **
 **	public void DisplayStudentCoursesRegistered( Student StudentObject ) - This method
 **	lists the courses that the student (StudentObject) has registered for.
 **
 **	public void DisplayStudentCoursesTaken( Student StudentObject ) - This method
 **	lists the courses that the student (StudentObject) has taken.
 **
 **	public void DisplayStudentList( StudentList ListObject ) - Displays the students 
 **	in the student list (ListObject).  Displays the same information that is listed 
 **	in the DisplayStudent() method listed above.
 **
 **	public void DisplayCourseList( CourseList ListObject ) - Displays the courses
 **	in the course list (ListObject).  Displays the same information that is listed
 **	in the DisplayCourse() method listed above.
 **
 ** Modification Log
 **************************************************************************************
 **
 **************************************************************************************/

class Displays {

    int LineCount = 0;
    int MaxLinesDisplayed = 18;

    private void LineCheck(int LinesToAdd) {

        Termio Terminal = new Termio();

        if (LineCount >= MaxLinesDisplayed) {

            LineCount = 0;
            System.out.print("\n*** Press Enter To Continue ***");
            Terminal.KeyboardReadChar();

        } else {

            LineCount += LinesToAdd;

        } // if 

    } // LineCheck

    public void DisplayStudent(Student StudentObject) {

        System.out.print(
            StudentObject.StudentID + " " + StudentObject.FirstName + " ");
        System.out.println(
             StudentObject.LastName + " "+ StudentObject.Program);

    } // DisplayStudent

    public void DisplayCourse(Course CourseObject) {

        System.out.print(
            CourseObject.CourseID + " " + CourseObject.Section + " ");
        System.out.print(CourseObject.CourseName + " " + CourseObject.Days + " ");
        System.out.print(
            CourseObject.StartTime + ":" + CourseObject.StopTime + " ");
        System.out.println(CourseObject.Instructor);

    } // DisplayCourse

    public void DisplayStudentsRegistered(Course CourseObject) {

        boolean Done;
        Student StudentObject;

        System.out.println("\nStudents Registered For: " + " ");
        LineCheck(2);

        System.out.print(
            CourseObject.CourseName + " " + CourseObject.CourseID + " ");
        System.out.print(CourseObject.Section + " " + CourseObject.Days + " ");
        System.out.print(
            CourseObject.StartTime + ":" + CourseObject.StopTime + " ");
        System.out.println(CourseObject.Instructor);
        LineCheck(1);

        System.out.println(
            "===========================================================");
        LineCheck(1);

        CourseObject.Registered.GoToFrontOfList();
        Done = false;

        while (!Done) {

            StudentObject = CourseObject.Registered.GetNextStudent();

            if (StudentObject == null) {

                Done = true;

            } else {

                DisplayStudent(StudentObject);

            } // if

        } // while

    } // DisplayStudentsRegistered

    public void DisplayStudentCoursesRegistered(Student StudentObject) {

        boolean Done;
        Course CourseObject;

        System.out.print(
            "\nCourses Registered For: " + StudentObject.FirstName + " ");
        System.out.println(
            StudentObject.LastName + " " + StudentObject.StudentID);
        LineCheck(2);
        System.out.println(
            "==================================================== ");
        LineCheck(1);

        StudentObject.CoursesRegistered.GoToFrontOfList();
        Done = false;

        while (!Done) {

            CourseObject = StudentObject.CoursesRegistered.GetNextCourse();

            if (CourseObject == null) {

                Done = true;

            } else {

                DisplayCourse(CourseObject);
                LineCheck(2);

            } // if

        } // while

    } // DisplayStudentCoursesRegistered

    public void DisplayStudentCoursesTaken(Student StudentObject) {

        boolean Done;
        Course CourseObject;

        System.out.print("\nCourses Taken: " + StudentObject.FirstName + " ");
        System.out.println(
            StudentObject.LastName + " " + StudentObject.StudentID);
        LineCheck(2);
        System.out.println("================================================ ");
        LineCheck(1);

        StudentObject.CoursesTakenList.GoToFrontOfList();
        Done = false;

        while (!Done) {

            CourseObject = StudentObject.CoursesTakenList.GetNextCourse();

            if (CourseObject == null) {

                Done = true;

            } else {

                System.out.print(CourseObject.CourseID);
                LineCheck(1);

            } // if

        } // while

    } // DisplayStudentCoursesTaken	

    public void DisplayStudentList(StudentList ListObject) {

        boolean Done;
        Student StudentObject;

        System.out.print("\n");
        LineCheck(1);

        ListObject.GoToFrontOfList();

        Done = false;

        while (!Done) {

            StudentObject = ListObject.GetNextStudent();

            if (StudentObject == null) {

                Done = true;

            } else {

                DisplayStudent(StudentObject);
                LineCheck(1);

            } // if

        } // while

    } // DisplayStudentList

    public void DisplayCourseList(CourseList ListObject) {

        boolean Done;
        Course CourseObject;

        System.out.print("\n");
        LineCheck(1);

        ListObject.GoToFrontOfList();
        Done = false;

        while (!Done) {

            CourseObject = ListObject.GetNextCourse();

            if (CourseObject == null) {

                Done = true;

            } else {

                DisplayCourse(CourseObject);
                LineCheck(1);

            } // if

        } // while

    } // DisplayCourseList

} // Display
