/**************************************************************************************
 ** Class name: StudentRegistration
 ** Author: A.J. Lattanze, CMU
 ** Date: 12/29/99
 ** Version 1.0
 **
 ** Adapted for use at ETS by Roger Champagne, 2002-May-21
 ***************************************************************************************
 ** Purpose: Assignment 2 for LOG420, Architecture et conception de logiciels.
 ** The purpose of this assignment is to introduce Multi-Tiered Object Oriented
 ** Architectures.  
 **
 ** Abstract: This program is a contrived student registration system. It is a menu 
 ** driven system that will allow the following options.
 **
 **	1) List Students
 **	2) List Courses
 **	3) List Courses a Student has Registered for
 **	4) List Students Registered for a Course
 **	5) Register a Student for a Course
 **	X) Exit
 ** 
 ** Structurally, the system is roughly divided into three layers: 1) A Presentation 
 ** Layer, 2) A Business Rule Layer, 3) A File I/O Layer. Dynamically, the main program
 ** (in this file) initializes the primary objects and dispatches commands at the 
 ** user's request.  When the program is started, the student objects are initialized 
 ** from a file (etudiantsLOG.txt is an example).  The format of this file is listed in
 ** the StudentReader class header.  The course objects are initialized from another 
 ** file (coursLOG.txt is an example).  The format of this file is listed in 
 ** the CourseReader class header.    
 **
 ** Pseudo Code:
 ** 
 ** 	Instantiate Student List
 ** 	Instantiate Course List
 **
 ** 	do until done
 **
 ** 		Present Menu
 **		if user choice = 1 then List Students
 **		if user choice = 2 then List Courses
 **		if user choice = 3 then List Students
 **		if user choice = 4 then 
 **			list students
 **			ask user to select a student
 **			list courses student is registered for
 **		if user choice = 5 then 
 **			list students
 **			ask user to select a student
 **			list courses
 **			ask user to select a course
 **			register student for course
 **		end if
 **		if user choice = x then you are done
 **
 ** 	end do
 **
 ** Running the program
 **
 ** StudentRegistration <CourseDataFile> <StudentDataFile>
 **
 **	An example course data file has been provided: coursLOG.txt
 **	An example student data file has been provided: etudiantsLOG.txt
 **
 ** Modification Log
 **************************************************************************************
 **
 **************************************************************************************/

public class StudentRegistration {

    public static void main(String argv[]) {

        if (argv.length != 2) {

            System.out.println(
                "\n\nIncorrect number of input parameters -"
                    + " correct usage:");

            System.out.println(
                "\nJava StudentRegistration <course file name>"
                    + " <student file name>");

        } else {

            // Declarations:

            boolean Done; // Loop invariant
            char UserChoice; // User's menu choice
            Course MyCourse = null; // A course object
            Student MyStudent = null; // A student object

            // Instantiates a menu object
            Menus Menu = new Menus();

            // Instantiates a display object
            Displays Display = new Displays();

            // The following instantiations create a list of courses and students.
            // The pathname for the file containing course information is passed to the 
            // main program on the command line as the first argument (argv[0]).  
            // The pathname for the file containing student information is passed to the 
            // main program on the command line as the second argument (argv[1]). An example
            // student file and course file is provided as etudiantsLOG.txt and 
            // coursLOG.txt 

            CourseReader MyCourseList = new CourseReader(argv[0]);
            StudentReader MyStudentList = new StudentReader(argv[1]);

            if ((MyCourseList.ListOfCourses == null)
                || (MyStudentList.ListOfStudents == null)) {

                System.out.println(
                    "\n\n *** The course list and/or the student"
                        + " list was not initialized ***");

                Done = true;

            } else {

                Done = false;

            } // if 

            while (!Done) {

                UserChoice = Menu.MainMenu();

                switch (UserChoice) {

                    case '1' :

                        Display.DisplayStudentList(
                            MyStudentList.ListOfStudents);
                        break;

                    case '2' :

                        Display.DisplayCourseList(MyCourseList.ListOfCourses);
                        break;

                    case '3' :

                        Display.DisplayStudentList(
                            MyStudentList.ListOfStudents);
                        MyStudent =
                            Menu.PickStudent(MyStudentList.ListOfStudents);

                        if (MyStudent != null) {

                            Display.DisplayStudentCoursesRegistered(MyStudent);

                        } // if

                        break;

                    case '4' :

                        Display.DisplayCourseList(MyCourseList.ListOfCourses);
                        MyCourse = Menu.PickCourse(MyCourseList.ListOfCourses);

                        if (MyCourse != null) {

                            Display.DisplayStudentsRegistered(MyCourse);

                        } // if 

                        break;

                    case '5' :

                        Display.DisplayStudentList(
                            MyStudentList.ListOfStudents);
                        MyStudent =
                            Menu.PickStudent(MyStudentList.ListOfStudents);

                        if (MyStudent != null) {

                            Display.DisplayCourseList(
                                MyCourseList.ListOfCourses);
                            MyCourse =
                                Menu.PickCourse(MyCourseList.ListOfCourses);

                            if (MyCourse != null) {

                                MyCourse.Register(MyStudent);
                                MyStudent.Register(MyCourse);

                            } // if 

                        } // if

                        break;

                    case 'X' :

                    case 'x' :
                        Done = true;

                } // switch

            } // while

        } // if

    } // main

} // Class
